@@ -255,7 +255,7 @@ DownsampleFeatures <- function(
 #' @export
 #' @concept preprocessing
 #' @examples
-#' FindTopFeatures(object = atac_small[['peaks']][])
+#' FindTopFeatures(object = atac_small[['peaks']]['data'])
 FindTopFeatures.default <- function(
   object,
   assay = NULL,
@@ -276,6 +276,7 @@ FindTopFeatures.default <- function(
 
 #' @rdname FindTopFeatures
 #' @importFrom SeuratObject GetAssayData VariableFeatures
+#' @importFrom utils packageVersion
 #' @export
 #' @method FindTopFeatures Assay
 #' @concept preprocessing
@@ -323,6 +324,30 @@ FindTopFeatures.Assay <- function(
   return(object)
 }
 
+#' @rdname FindTopFeatures
+#' @importFrom SeuratObject GetAssayData VariableFeatures
+#' @importFrom utils packageVersion
+#' @export
+#' @method FindTopFeatures StdAssay
+#' @concept preprocessing
+#' @examples
+#' FindTopFeatures(object = atac_small[['peaks']])
+FindTopFeatures.StdAssay <- function(
+    object,
+    assay = NULL,
+    min.cutoff = "q5",
+    verbose = TRUE,
+    ...
+) {
+  FindTopFeatures.Assay(
+    object = object,
+    assay = assay,
+    min.cutoff = min.cutoff,
+    verbose = verbose,
+    ...
+  )
+}
+
 #' @rdname FindTopFeatures
 #' @importFrom SeuratObject DefaultAssay
 #' @export
@@ -729,6 +754,32 @@ RunTFIDF.Assay <- function(
   return(object)
 }
 
+#' @rdname RunTFIDF
+#' @method RunTFIDF StdAssay
+#' @export
+#' @concept preprocessing
+#' @examples
+#' RunTFIDF(atac_small[['peaks']])
+RunTFIDF.StdAssay <- function(
+    object,
+    assay = NULL,
+    method = 1,
+    scale.factor = 1e4,
+    idf = NULL,
+    verbose = TRUE,
+    ...
+) {
+  RunTFIDF.Assay(
+    object = object,
+    assay = assay,
+    method = method,
+    scale.factor = scale.factor,
+    idf = idf,
+    verbose = verbose,
+    ...
+  )
+}
+
 #' @param assay Name of assay to use
 #' @rdname RunTFIDF
 #' @method RunTFIDF Seurat
