@@ -254,6 +254,59 @@ ClosestFeature <- function(
   return(df)
 }
 
+
+#' Sparse matrix correlation
+#' 
+#' Compute the Pearson correlation matrix between
+#' columns of two sparse matrices.
+#' 
+#' Originally from 
+#' \url{https://stackoverflow.com/questions/5888287/running-cor-or-any-variant-over-a-sparse-matrix-in-r}
+#' and the qlcMatrix package.
+#' 
+#' @param X A matrix
+#' @param Y A matrix
+#' @param cov return covariance matrix
+#' @export
+#' @keywords internal
+#' @author Michael Cysouw, Karsten Looschen
+#' @importMethodsFrom Matrix colMeans
+# covmat uses E[(X-muX)'(Y-muY)] = E[X'Y] - muX'muY
+# with sample correction n/(n-1) this leads to cov = ( X'Y - n*muX'muY ) / (n-1)
+#
+# the sd in the case Y!=NULL uses E[X-mu]^2 = E[X^2]-mu^2
+# with sample correction n/(n-1) this leads to sd^2 = ( X^2 - n*mu^2 ) / (n-1)
+#
+# Note that results larger than 1e4 x 1e4 will become very slow, because the resulting matrix is not sparse anymore.
+corSparse <- function(X, Y = NULL, cov = FALSE) {
+  X <- as(object = X, Class = "CsparseMatrix")
+  n <- nrow(x = X)
+  muX <- colMeans(x = X)
+  
+  if (!is.null(x = Y)) {
+    if (nrow(x = X) != nrow(x = Y)) {
+      stop("Matrices must contain the same number of rows")
+    }
+    Y <- as(object = Y, Class = "CsparseMatrix")
+    muY <- colMeans(x = Y)
+    covmat <- ( as.matrix(x = crossprod(x = X, y = Y)) - n * tcrossprod(x = muX, y = muY) ) / (n-1)
+    sdvecX <- sqrt( (colSums(x = X^2) - n*muX^2) / (n-1) )
+    sdvecY <- sqrt( (colSums(x = Y^2) - n*muY^2) / (n-1) )
+    cormat <- covmat / tcrossprod(x = sdvecX, y = sdvecY)
+  } else {		
+    covmat <- ( as.matrix(crossprod(x = X)) - n * tcrossprod(x = muX) ) / (n-1)
+    sdvec <- sqrt(x = diag(x = covmat))
+    cormat <- covmat / tcrossprod(x = sdvec)
+  }
+  if (cov) {
+    dimnames(x = covmat) <- NULL
+    return(covmat)
+  } else {
+    dimnames(x = cormat) <- NULL
+    return(cormat)
+  }
+}
+
 #' Create gene activity matrix
 #'
 #' Compute counts per cell in gene body and promoter region.
@@ -863,7 +916,7 @@ LookupGeneCoords <- function(object, gene, assay = NULL) {
 #' @param ... Arguments passed to other functions
 #' @return Returns a character vector
 #'
-#' @importFrom stats density approx
+#' @importFrom stats density approx na.omit
 #' @export
 #' @concept utilities
 #' @concept motifs
@@ -896,6 +949,8 @@ MatchRegionStats <- function(
   if (length(x = features.match) == 0) {
     stop("Must supply at least one sequence characteristic to match")
   }
+  # remove features that have NA for any of the features to match
+  meta.feature <- na.omit(object = meta.feature[, features.match, drop = FALSE])
   if (nrow(x = meta.feature) < n) {
     n <- nrow(x = meta.feature)
     warning("Requested more features than present in supplied data.
@@ -917,11 +972,10 @@ MatchRegionStats <- function(
     density.estimate <- density(
       x = query.feature[[featmatch]], kernel = "gaussian", bw = 1
     )
-    mf.use <- meta.feature[!is.na(x = meta.feature[[featmatch]]), ]
     weights <- approx(
       x = density.estimate$x,
       y = density.estimate$y,
-      xout = mf.use[[featmatch]],
+      xout = meta.feature[[featmatch]],
       yright = 0.0001,
       yleft = 0.0001
     )$y
@@ -932,11 +986,11 @@ MatchRegionStats <- function(
     }
   }
   feature.select <- sample.int(
-    n = nrow(x = mf.use),
+    n = nrow(x = meta.feature),
     size = n,
     prob = feature.weights
   )
-  feature.select <- rownames(x = mf.use)[feature.select]
+  feature.select <- rownames(x = meta.feature)[feature.select]
   return(feature.select)
 }
 
@@ -2263,15 +2317,12 @@ SparsifiedRanks <- function(X){
 }
 
 SparseSpearmanCor <- function(X, Y = NULL, cov = FALSE) {
-  if (!requireNamespace(package = "qlcMatrix", quietly = TRUE)) {
-    stop("Please install qlcMatrix: install.packages('qlcMatrix')")
-  }
   # Get sparsified ranks
   rankX <- SparsifiedRanks(X = X)
   if (is.null(Y)){
     # Calculate pearson correlation on rank matrices
-    return (qlcMatrix::corSparse(X = rankX, cov = cov))
+    return (corSparse(X = rankX, cov = cov))
     }
   rankY <- SparsifiedRanks(X = Y)
-  return(qlcMatrix::corSparse(X = rankX, Y = rankY, cov = cov))
+  return(corSparse(X = rankX, Y = rankY, cov = cov))
 }
